Danube Delta
============

`Honza Javorek <https://github.com/honzajavorek/>`__'s `Pelican <http://www.getpelican.com/>`__ setup.

.. image:: https://travis-ci.org/honzajavorek/danube-delta.svg?branch=master
    :target: https://travis-ci.org/honzajavorek/danube-delta

Installation
------------

.. code:: shell

    $ pip install danube-delta

Name
----

I've seen some `pelicans <https://en.wikipedia.org/wiki/Pelican>`__ in the `Danube Delta <https://en.wikipedia.org/wiki/Danube_Delta>`__...
